%define sname   knights

# Using the website's domain name to differentiate this game from KDE games' Knights
Name:           knightsgame
Version:        27
Release:        %mkrel 3
Summary:        Multiplayer objective-oriented game with knights questing in a dungeon
Group:          Games/Arcade
License:        GPLv3+
URL:            https://www.knightsgame.org.uk/
Source0:        https://www.knightsgame.org.uk/files/%{sname}_0%{version}_src.tar.gz
Patch0:		knightsgame-cflags.patch
Patch1:		knightsgame-missing-includes.patch
BuildRequires:  boost-devel
BuildRequires:  icoutils
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libenet)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(sdl2)

%description
Knights is a multiplayer game involving several knights who must run
around a dungeon and complete various quests.

Each game revolves around a quest that all players compete to achieve,
such as retrieving some items to carry them back to their starting
point, escaping from the dungeon, fighting a duel to death against
the enemy knights, or destroying an ancient book using a special wand.

%prep
%autosetup -p1 -n %{sname}_0%{version}_src

sed -i 's|pkg-config lua-c++|pkg-config lua|g' Makefile

%build
%set_build_flags
export CXXFLAGS="%{optflags} -pthread -Wno-deprecated-declarations"

%make_build BIN_DIR=%{_gamesbindir} \
      DATA_DIR=%{_gamesdatadir}/%{name} \
      KNIGHTS_BINARY_NAME=%{name} \
      SERVER_BINARY_NAME=%{name}-server

%install
%make_build BIN_DIR=%{buildroot}%{_gamesbindir} \
      DATA_DIR=%{buildroot}%{_gamesdatadir}/%{name} \
      KNIGHTS_BINARY_NAME=%{name} \
      SERVER_BINARY_NAME=%{name}-server \
      install_knights \
      install_server

for size in 16 32 48; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/${size}x${size}/apps/
  icotool -x --width=${size} --output=%{buildroot}%{_iconsdir}/hicolor/${size}x${size}/apps/%{name}.png ./src/icon.ico
done

# Menu entry
mkdir -p %{buildroot}%{_datadir}/applications/
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Knights
Comment=Multiplayer objective-oriented game with knights questing in a dungeon
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
StartupNotify=true
Categories=Game;ArcadeGame;
EOF

%files
%doc docs/ACKNOWLEDGMENTS.txt docs/COPYRIGHT.txt docs/README.txt docs/style.css docs/manual/
%{_datadir}/applications/%{name}.desktop
%{_gamesbindir}/%{name}*
%{_gamesdatadir}/%{name}/client/*
%{_gamesdatadir}/%{name}/server/*
%{_iconsdir}/hicolor/*/apps/%{name}.png


%changelog
* Sun Feb 09 2025 wally <wally> 27-3.mga10
+ Revision: 2146234
- rebuild for boost 1.87.0

* Fri Sep 13 2024 wally <wally> 27-2.mga10
+ Revision: 2095480
- rebuild for boost 1.86.0

* Thu Jun 27 2024 daviddavid <daviddavid> 27-1.mga10
+ Revision: 2077346
- new version: 27
- switch to sdl2

* Wed Jun 19 2024 wally <wally> 25-26.mga10
+ Revision: 2075351
- rebuild for boost 1.85.0

* Thu Jan 18 2024 wally <wally> 25-25.mga10
+ Revision: 2031926
- add patch to fix build with new gcc
- rebuild for boost 1.84.0

* Wed Sep 27 2023 wally <wally> 25-24.mga10
+ Revision: 1991455
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 25-23.mga9
+ Revision: 1926489
- rebuild for boost 1.81.0

* Sun Jul 03 2022 wally <wally> 25-22.mga9
+ Revision: 1867265
- rebuild for boost 1.79.0

* Fri Apr 01 2022 umeabot <umeabot> 25-21.mga9
+ Revision: 1839303
- Mageia 9 Mass Rebuild

* Sun Dec 19 2021 wally <wally> 25-20.mga9
+ Revision: 1762643
- rebuild for boost 1.78.0

* Sat Sep 11 2021 wally <wally> 25-19.mga9
+ Revision: 1745179
- add patch to fix missing includes
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 25-18.mga9
+ Revision: 1722974
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 25-17.mga8
+ Revision: 1666772
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 25-16.mga8
+ Revision: 1662014
- rebuild for boost 1.74.0

* Sun May 03 2020 wally <wally> 25-15.mga8
+ Revision: 1578069
- rebuild for boost 1.73.0

* Wed Apr 15 2020 danf <danf> 25-14.mga8
+ Revision: 1567469
- Fix Comment= in .desktop file to stop referring to debug sources

* Wed Feb 19 2020 umeabot <umeabot> 25-13.mga8
+ Revision: 1544759
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 25-12.mga8
+ Revision: 1483386
- rebuild for boost 1.72.0
- replace deprecated %%setup_compile_flags

* Wed Oct 17 2018 wally <wally> 25-11.mga7
+ Revision: 1321822
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 25-10.mga7
+ Revision: 1298604
- Mageia 7 Mass Rebuild

* Mon Dec 25 2017 wally <wally> 25-9.mga7
+ Revision: 1184678
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 25-8.mga7
+ Revision: 1178113
- rebuild for boost 1.65

* Fri Sep 15 2017 cjw <cjw> 25-7.mga7
+ Revision: 1153913
- use mageia CFLAGS/CXXFLAGS to fix debug packages

* Sat Dec 26 2015 daviddavid <daviddavid> 25-6.mga6
+ Revision: 915362
- rebuild for new boost 1.60.0

* Sat Sep 26 2015 daviddavid <daviddavid> 25-5.mga6
+ Revision: 883811
- rebuild for new boost 1.59.0

* Sun Aug 02 2015 daviddavid <daviddavid> 25-4.mga6
+ Revision: 860557
- rebuild for new boost-1.58.0

* Wed Oct 15 2014 umeabot <umeabot> 25-3.mga5
+ Revision: 742537
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 25-2.mga5
+ Revision: 681141
- Mageia 5 Mass Rebuild

* Thu Aug 07 2014 akien <akien> 25-1.mga5
+ Revision: 660329
- Version 25

* Sun Jul 06 2014 akien <akien> 24-1.mga5
+ Revision: 644146
- Version 24

* Sat Feb 22 2014 akien <akien> 23-1.mga5
+ Revision: 595676
- imported package knightsgame

